import React, { useState, useEffect } from 'react';
import {
  Table,
  Modal,
  Form,
  Input,
  Space,
  Button,
  Popconfirm,
  notification,
  message,
} from 'antd';
import { get } from '@/services/index';
import styles from './WebDic.less';

const WebDic = () => {
  const [loading, setLoading] = useState(false);
  const [editVisible, setEditVisible] = useState(false);
  // const [editValue, setEditValue] = useState('');
  // const [description, setDescription] = useState('');
  const [data, setData] = useState([]);
  const [subData, setSubData] = useState([]);
  const [select, setSelect] = useState({});
  const [editForm] = Form.useForm();

  const columns = [
    {
      title: '名称',
      dataIndex: 'nodeName',
      key: 'nodeName',
      width: 300,
    },
    {
      title: '值',
      dataIndex: 'nodeValue',
      key: 'nodeValue',
    },
    {
      title: '操作',
      key: 'action',
      width: 200,
      render: record => (
        <Space>
          <Button
            type="primary"
            size="small"
            onClick={e => {
              e.stopPropagation();
              setSelect(record);
              setEditVisible(true);
              console.log(record);
              editForm.setFieldsValue({
                nodeName: record.nodeName,
                nodeValue: record.nodeValue,
              });
            }}
          >
            修改
          </Button>
          <Popconfirm
            title="是否删除该数据？"
            okText="确认"
            cancelText="取消"
            // onConfirm={submitDelete}
          >
            <Button
              size="small"
              danger
              onClick={e => {
                e.stopPropagation();
                setSelect(record);
              }}
            >
              删除
            </Button>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  useEffect(() => {
    getData('-1');
  }, []);
  const getData = value => {
    setLoading(true);
    get(`/Cityinterface/rest/services/OMS.svc/D_GetDataDictionaryList`, {
      _version: 9999,
      _dc: new Date().getTime(),
      nodeID: value,
      key: '',
    })
      .then(res => {
        if (res.length > 0) {
          res.map(item => {
            item.key = item.nodeID;
            return item;
          });
          if (value === '-1') {
            setData(res); // 设置一级条目
          } else if (value) {
            setSubData(res); // 设置二级条目
          }
          // 获取二级条目
          if (res && res[0] && res[0].parentID === '-1') {
            getData(res[0].nodeID);
          }
        } else {
          notification.error({
            message: '获取失败',
            description: res.message,
          });
        }
        setLoading(false);
      })
      .catch(err => {
        setLoading(false);
        message.error(err);
      });
  };
  const setRowClassName = record =>
    record.nodeID === select.nodeID ? styles.clickRowStyle : '';

  const submitEdit = () => {
    const nodeName = editForm.getFieldValue('nodeName');
    const nodeValue = editForm.getFieldValue('nodeValue');
  };

  return (
    <div className={styles.WebDic}>
      <Table
        size="small"
        bordered
        columns={columns}
        dataSource={data}
        scroll={{ x: 'max-content' }}
        rowClassName={setRowClassName}
        onRow={record => ({
          onClick: () => {
            getData(record.nodeID);
            setSelect(record);
          },
        })}
        pagination={{
          showTotal: (total, range) =>
            `第${range[0]}-${range[1]} 条/共 ${total} 条`,
          pageSizeOptions: [10, 20, 50, 100],
          showQuickJumper: true,
          showSizeChanger: true,
        }}
      />
      <Table
        size="small"
        bordered
        columns={columns}
        dataSource={subData}
        scroll={{ x: 'max-content' }}
        pagination={{
          showTotal: (total, range) =>
            `第${range[0]}-${range[1]} 条/共 ${total} 条`,
          pageSizeOptions: [10, 20, 50, 100],
          showQuickJumper: true,
          showSizeChanger: true,
        }}
      />
      {/* 修改 */}
      <Modal
        title={select.parentID === '-1' ? '修改一级条目' : '修改二级条目'}
        visible={editVisible}
        onOk={submitEdit}
        onCancel={() => {
          setEditVisible(false);
        }}
        okText="确认"
        cancelText="取消"
      >
        <Form form={editForm} labelCol={{ span: 3 }}>
          <Form.Item
            name="nodeName"
            label="名称"
            rules={[{ required: true, message: '不能为空' }]}
          >
            <Input placeholder="请输入名称" />
          </Form.Item>
          {select.nodeID !== '-1' && (
            <Form.Item
              name="nodeValue"
              label="值"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入值" />
            </Form.Item>
          )}
        </Form>
      </Modal>
    </div>
  );
};

export default WebDic;
